@@ -4,7 +4,7 @@ from collections import namedtuple
 
 from shapy.framework.netlink.message import Attr
 from shapy.framework.utils import nl_ticks2us, nl_us2ticks
-from .constants import *
+from shapy.framework.netlink.constants import *
 
 
 
@@ -32,6 +32,7 @@ class NetemOptions(Attr):
     def __init__(self, latency, limit=1000, loss=0, gap=0, duplicate=0, jitter=0):
         """Latency is in microseconds [us]"""
         latency_ticks = nl_us2ticks(latency)
+        jitter_ticks = nl_us2ticks(jitter)
         data = self.data_format.pack(latency_ticks, limit, loss,
-                                     gap, duplicate, jitter)
+                                     gap, duplicate, jitter_ticks)
         Attr.__init__(self, TCA_OPTIONS, data)
